import { Component } from 'preact';
import { route } from 'preact-router';
import style from '../routes/home/style';
import axios from 'axios';
import SyntaxHighlighter from 'react-syntax-highlighter';
import { atomOneDark } from 'react-syntax-highlighter/dist/esm/styles/hljs';
import { getCookie, deleteCookie } from './utils';

export default class ComprehensionSnippet extends Component {
    constructor(props) {
        super();
        this.state = {
            comments: '',
            email: '',
            completed: false
        };

        this.handleTextChange = this.handleTextChange.bind(this);
        this.submitClosingForm = this.submitClosingForm.bind(this);
	}
    
    handleTextChange(e) {
        const name = e.target.name;
        if (name == 'comments') {
            this.setState({ comments: e.target.value });
        } else if (name == 'email') {
            this.setState({ email: e.target.value });
        }
    }

    submitClosingForm(e) {
        e.preventDefault();
        const sessionId = getCookie('session_id');
        if (sessionId) {
            const postData = {
                sessionId,
                comments: this.state.comments,
                email: this.state.email
            }
			axios.post('/api/completeSurvey', postData).then(result => {
				if (result.data && result.data.success) {
                    if (result.data.type && result.data.type == 'demo') {
                        console.log('deleting cookie')
                        deleteCookie('session_id');
                    }
                    this.setState({ completed: true });
				} else {
                    alert('Failure');
					route('/', true);
				}
			});
		} else {
			route('/', true);
		}
    }

    render() {
        if (this.state.completed) {
            return (<div class={style.home}>
                <h1>Thank you for completing the survey!</h1>
            </div>)
        }
        return (<div class={style.home}>
            <h1>Thank you</h1>
            <p>You have completed the survey.</p>
            <p>If you have any comments, please list them below:</p>
            <form onSubmit={this.submitClosingForm}>
                <label for="comments">Comments</label>
                <textarea name="comments" id="comments" value={this.state.comments} onChange={this.handleTextChange} />
                <p>If you would like to be entered for a prize, please provide your email address below (completely optional).</p>
                <label for="email">Email</label>
                <input type="text" name="email" id="email" value={this.state.email} onChange={this.handleTextChange} />
                <button type="submit">Submit</button>
            </form>
        </div>)
    }
}