import { h, render, Component } from 'preact';
import style from './style';
import axios from 'axios';
import { UnControlled as CodeMirror} from 'react-codemirror2'
require('codemirror/mode/clike/clike');
require('codemirror/lib/codemirror.css')
require('codemirror/theme/material.css')

class Home extends Component {
	constructor() {
		super();
		this.state = { userType: 'pilot', value: '' };
		this.onSignup = this.onSignup.bind(this);
		this.onSelect = this.onSelect.bind(this);
		this.test = this.test.bind(this);
	}

	onSignup(e) {
		e.preventDefault();
		const { signup } = this.props;
		signup(this.state.userType)
	}

	componentDidMount() {
		this.props.login();
	}

	onSelect(e) {
		this.setState({ userType: e.target.value });
	}

	test(editor, data, value) {
		console.log(data);
		this.setState({ value });
	}

	render() {
		const { login } = this.props;
		return (
			<div class={style.home}>
				<h1>About</h1>

				<p>Program comprehension is an important aspect of software engineering.
				Engineers spend a large amount of their time understanding code that has
				previously been written by themselves or other engineers.  In recent
				years, the advent of artificial intelligence has led to a growth in
				techniques for automatically documenting or summarizing code.</p>

				<p>With this survey, we hope to understand how automatic summarization
				techniques may benefit human engineers involved in program comprehension
				tasks.</p>

				<p>If you choose to participate, you will be presented with snippets of
				code and a corresponding summary for that snippet.  Then, you will be
				sked to answer questions about each code snippet.</p>

				<p>This survey is voluntary; you can stop at any time.  We will not ask for
				your name nor will we record personally identifiable information.  Data
				collected in this survey will be used to learn how quickly and accurately
				humans can understand code snippets.</p>

				<p>No special experience is required to complete this survey. There is no time
				limit, but most people will complete the survey in 30 minutes or less.</p>

				<strong>This is a pilot study.  There may be bugs, issues with clarity,
				or other problems that we have not yet encountered.  Please let us know
				if you encounter any issue either via the email below or in the comments
				at the end of the survey.</strong>

				<p>The investigator can be contacted at:</p>
				<ul>
					<li>Dr. Kevin Leach (<a href="mailto:kjleach@umich.edu">kjleach@umich.edu</a>)</li>
				</ul>


				<h1>Instructions</h1>

				<p>You will be shown a snippet of Java code on the left, and either (1)
				a machine-generated summary, (2) a human-written summary, or (3) no
				summary for that snippet. 
				We will ask you a program comprehension question about the snippet.
				Please answer the question given the
				information you have available to you.  We will record how long it
				takes you, and whatever freeform answer you enter.</p>

				<p>In the snippets of code in the survey, you can assume that <code>WIN32</code> is not defined.</p>

				<h1>Start</h1>
				<form onSubmit={this.onSignup}>
					<br />
					<label for="location">Please indicate your location</label>
					<select id="location" name="location" value={this.state.userType} onChange={this.onSelect}>
						<option value="pilot">Pilot study participant</option>
						<option value="umugrad">UMich undergraduate student</option>
						<option value="umgrad">UMich graduate student</option>
						<option value="ndugrad">Notre Dame undergraduate student</option>
						<option value="ndgrad">Notre Dame graduate student</option>
						<option value="clinc">Clinc employee</option>
						<option value="other">Other/Not listed</option>
						<option value="demo">demo</option>
					</select>
					<input type="submit" value="Start survey" />
				</form>
			</div>
		)
	}
}

export default Home;
